<?php
namespace BriefcasewpExtras;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Extensions
 *
 * Extensions handles
 *
 * @since 1.0.0
 */
class Extensions {

	/**
	 * Plugin page.
	 *
	 * Holds slug for plugin page.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @var string
	 */
	private $extensions_page = 'bew-extensions';

	/**
	 * Plugin menu link.
	 *
	 * Adds link to admin menu under Wordpress menu
	 *
	 * Fired by `admin_menu` action.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function admin_pages() {
		// Addons submenu
		add_submenu_page( 
			'bew-templates', 
			'Extensions', 
			'Extensions', 
			'manage_options', 
			'briefcasewp_extensions', 
			array( $this, 'bew_addons_extensions' )
		);		

	}
		
	/**
	* Admin Screen for extensions
	*/
	function bew_addons_extensions() {
    // Get all extensions
    $all_extensions    = ext_get_extensions();
    // Get active extensions
    $active_extensions = ext_get_active_extensions();
	
	// Get Credentials for update the options.
	$options = get_site_option('briefcase-elementor-widgets_updater_options');
	$email= isset($options['email']) ? $options['email'] : '';		
	$check_password = !empty(isset($options['password'])) ? "yes" : "no";
		
	if ($check_password == "no"){
		//Check if is password is set.
		$option_bew_extras = get_site_option('bew_extras_options');
		$check_password_confirm = !empty(isset($option_bew_extras['confirm_password'])) ? "yes" : "no";
	}
			
    ?>
    <div class="wrap">
        <h1><?php echo get_admin_page_title(); ?></h1>
		
        <?php if (($email != '' && $check_password == "yes") || $check_password_confirm == "yes"  ){ ?>
		<p><?php _e( 'All Briefcasewp Extensions. Choose which to use and activate them.', 'briefcasewp-extras' ); ?></p>
		<?php } else { ?>
		<div class="activate-notice">
			<p><?php _e( 'Activate Briefcase Elementor Widgets plugin to use the extensions. Please enter your customer login and password at the top, then refresh the page.', 'briefcasewp-extras' ); ?></p>
		</div>
		<?php } ?>				
     
		<div class="wp-list-table widefat plugin-install">
			<div id="the-list">
				<?php					
				if( $all_extensions ) {
					foreach ( $all_extensions as $slug => $class ) {
						if( ! class_exists( $class ) ) {
							continue;
						}
						// Instantiate each extension
						$extension_object = new $class();
						// We will use this object to get the title, description and image of the extension.
						?>
						<div class="plugin-card plugin-card-<?php echo $slug; ?>">
							<div class="plugin-card-top">
								<div class="name column-name">
									<h3>
										<?php echo $extension_object->title; ?>                    
										<img src="<?php echo $extension_object->image; ?>" class="plugin-icon" alt="">
									</h3>
								</div>
								<div class="desc column-description">
									<p><?php echo $extension_object->desc; ?></p>
								</div>
							</div>
							<div class="plugin-card-bottom">
							<?php 
							// Use the buttons from our Abstract class to create the buttons
							// Can be overwritten by each integration if needed.
							if (($email != '' && $check_password == "yes") || $check_password_confirm == "yes"  ){
								$extension_object->buttons( $active_extensions ); 
							} 
							?>
							</div>
						</div>
					<?php
					}
				}					
			?>
			</div>
		</div>
    </div> 
<?php
}


	/**
	 * Extensions constructor.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		add_action( 'admin_menu', [ $this, 'admin_pages' ], 50 ); //as last item
	}
}
